.. _fluent_pages.integration.fluent_contents:

fluent_pages.integration.fluent_contents
========================================

.. automodule:: fluent_pages.integration.fluent_contents

The ``FluentContentsPageAdmin`` class
-------------------------------------

.. autoclass:: fluent_pages.integration.fluent_contents.admin.FluentContentsPageAdmin
   :members:

The ``FluentContentsPage`` class
--------------------------------

.. autoclass:: fluent_pages.integration.fluent_contents.models.FluentContentsPage
   :members:

The ``FluentContentsPagePlugin`` class
--------------------------------------

.. autoclass:: fluent_pages.integration.fluent_contents.page_type_plugins.FluentContentsPagePlugin
   :members:
